Description Usage Arguments Value Slots Objects from the Class Extends Methods Author(s) See Also Examples
Container for a list of filter
objects. The class mainly exists for method dispatch.
1 | filterList(x, filterId=identifier(x[[1]]))
|
x |
A list of |
filterId |
The global identifier of the filter list. As default, we
take the filterId of the first |
A filterList object for the constructor.
.DataObject of class "list". The class
directly extends list, and this slot holds the list data.
filterIdObject of class "character". The
identifier for the object.
Objects are created from regular lists
using the constructor filterList.
Class "list", from data part.
signature(object = "filterList"): Print
details about the object.
signature(object =
"filterList"): Accessor and replacement method for the object's
filterId slot.
Florian Hahne
1 2 3 4 5 | f1 <- rectangleGate(FSC=c(100,200), filterId="testFilter")
f2 <- rectangleGate(FSC=c(200,400))
fl <- filterList(list(a=f1, b=f2))
fl
identifier(fl)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.